<?php
/**
 * The header for our theme
 *
 * This is the template that displays all of the <head> section and everything up until <div id="content">
 *
 * @link https://developer.wordpress.org/themes/basics/template-files/#template-partials
 *
 * @package Travellabe_Pro
 */

?>
<!doctype html>
<html <?php language_attributes(); ?>>
<head>
	<meta charset="<?php bloginfo( 'charset' ); ?>">
	<meta name="viewport" content="width=device-width, initial-scale=1.0">
	<link rel="profile" href="https://gmpg.org/xfn/11">

	<?php wp_head(); ?>
</head>

<body <?php body_class(); ?>>
<?php wp_body_open(); ?>
<div id="page" class="site">
	<a class="skip-link screen-reader-text" href="#primary"><?php esc_html_e( 'Skip to content', 'travellable' ); ?></a>
	<header id="masthead" class="site-header">
		<?php if ( get_theme_mod( 'travellable_enable_top_bar', true ) ) { ?>
			<div class="header-top">
				<div class="container">
					<div class="header-top-left">
						<?php
						$contact_number = get_theme_mod( 'travellable_contact_number' );
						if ( ! empty( $contact_number ) ) {
							?>
							<span><a href="<?php echo esc_attr( $contact_number ); ?>" class="pe-4 kerning-1"><em class="bi bi-telephone"></em> <?php echo esc_html( $contact_number ); ?></a></span>
							<?php
						}
						?>
					</div> <!-- .header-top-left -->
					<div class="header-top-right">
						<div class="top-links">
							<?php
							if ( has_nav_menu( 'social' ) ) {
								wp_nav_menu(
									array(
										'menu_class'     => 'menu social-links',
										'link_before'    => '<span class="screen-reader-text">',
										'link_after'     => '</span>',
										'theme_location' => 'social',

									)
								);
							}
							?>
							<?php if ( get_theme_mod( 'travellable_enable_search_form', true ) ) { ?>
								<a class="top-links__default" href="#" id="header-search-toggler"> <em class="bi bi-search"></em> </a>
								<div class="header-search-wrapper" id="header-search">
									<?php get_search_form(); ?>
								</div>
							<?php } ?>
						</div>
					</div> <!-- .header-top-right -->
				</div> <!-- .header-top -->
			</div>
		<?php } ?>
		<div class="header-bottom">
			<div class="container">
				<div class="site-branding">
					<div class="site-logo">
						<?php the_custom_logo(); ?>
					</div>
					<div class="site-identity">
						<?php
						if ( is_front_page() && is_home() ) :
							?>
							<h1 class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1>
							<?php
						else :
							?>
							<p class="site-title"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></p>
							<?php
						endif;
						$travellable_description = get_bloginfo( 'description', 'display' );
						if ( $travellable_description || is_customize_preview() ) :
							?>
							<p class="site-description"><?php echo esc_html( $travellable_description ); // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped ?></p>
							<?php
						endif;
						?>
					</div>
				</div><!-- .site-branding -->
				<nav id="site-navigation" class="main-navigation">
					<button id="nav-icon" class="menu-toggle" aria-controls="primary-menu" aria-expanded="false">
						<span></span>
						<span></span>
						<span></span>
						<span></span>
					</button>
					<div class="main-menu">
					<?php
					wp_nav_menu(
						array(
							'theme_location' => 'primary',

						)
					);
					?>
					</div>
				</nav><!-- #site-navigation -->
			</div>
		</div>
	</header><!-- #masthead -->
	<?php if ( ! is_front_page() || is_home() ) { ?>
		<div id="content" class="site-content">
			<div class="container">
				<div class="row">
	<?php } ?>
