<?php
/**
 * Blog Section
 *
 * @package Travellable
 */

$wp_customize->add_section(
	'travellable_blog_section',
	array(
		'panel' => 'travellable_front_page_options',
		'title' => esc_html__( 'Blog Section', 'travellable' ),
	)
);

// Blog Section - Enable Section.
$wp_customize->add_setting(
	'travellable_enable_blog_section',
	array(
		'default'           => false,
		'sanitize_callback' => 'travellable_sanitize_switch',
	)
);

$wp_customize->add_control(
	new Travellable_Toggle_Switch_Custom_Control(
		$wp_customize,
		'travellable_enable_blog_section',
		array(
			'label'    => esc_html__( 'Enable Blog Section', 'travellable' ),
			'section'  => 'travellable_blog_section',
			'settings' => 'travellable_enable_blog_section',
			'type'     => 'checkbox',
		)
	)
);

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial(
		'travellable_enable_blog_section',
		array(
			'selector' => '#travellable_blog_section .section-link',
			'settings' => 'travellable_enable_blog_section',
		)
	);
}

// Blog Section - Section Title.
$wp_customize->add_setting(
	'travellable_blog_title',
	array(
		'default'           => __( 'Blog', 'travellable' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'travellable_blog_title',
	array(
		'label'           => esc_html__( 'Section Title', 'travellable' ),
		'section'         => 'travellable_blog_section',
		'settings'        => 'travellable_blog_title',
		'type'            => 'text',
		'active_callback' => 'travellable_is_blog_section_enabled',
	)
);

// Blog Section - Number of Posts.
$wp_customize->add_setting(
	'travellable_blog_count',
	array(
		'default'           => 6,
		'sanitize_callback' => 'travellable_sanitize_number_range',
		'validate_callback' => 'travellable_validate_blog_count',
	)
);

$wp_customize->add_control(
	'travellable_blog_count',
	array(
		'label'           => esc_html__( 'Number of Items to Show', 'travellable' ),
		'description'     => esc_html__( 'Note: Min 3 & Max 12. Please input the valid number and save. Then refresh the page to see the change.', 'travellable' ),
		'section'         => 'travellable_blog_section',
		'settings'        => 'travellable_blog_count',
		'type'            => 'number',
		'input_attrs'     => array(
			'min' => 3,
			'max' => 12,
		),
		'active_callback' => 'travellable_is_blog_section_enabled',
	)
);

// List out selected number of fields.
$blog_count = get_theme_mod( 'travellable_blog_count', 6 );

for ( $i = 1; $i <= $blog_count; $i++ ) {
	// Blog Section - Select Post.
	$wp_customize->add_setting(
		'travellable_blog_content_post_' . $i,
		array(
			'sanitize_callback' => 'absint',
		)
	);

	$wp_customize->add_control(
		'travellable_blog_content_post_' . $i,
		array(
			'label'           => esc_html__( 'Select Post ', 'travellable' ) . $i,
			'section'         => 'travellable_blog_section',
			'settings'        => 'travellable_blog_content_post_' . $i,
			'type'            => 'select',
			'active_callback' => 'travellable_is_blog_section_enabled',
			'choices'         => travellable_get_post_choices(),
		)
	);

}

// Blog Section - Button Label.
$wp_customize->add_setting(
	'travellable_blog_button_label',
	array(
		'default'           => __( 'View All', 'travellable' ),
		'sanitize_callback' => 'sanitize_text_field',
	)
);

$wp_customize->add_control(
	'travellable_blog_button_label',
	array(
		'label'           => esc_html__( 'Button Label', 'travellable' ),
		'section'         => 'travellable_blog_section',
		'settings'        => 'travellable_blog_button_label',
		'type'            => 'text',
		'active_callback' => 'travellable_is_blog_section_enabled',
	)
);

// Blog Section - Button Link.
$wp_customize->add_setting(
	'travellable_blog_button_link',
	array(
		'default'           => '',
		'sanitize_callback' => 'esc_url_raw',
	)
);

$wp_customize->add_control(
	'travellable_blog_button_link',
	array(
		'label'           => esc_html__( 'Button Link', 'travellable' ),
		'section'         => 'travellable_blog_section',
		'settings'        => 'travellable_blog_button_link',
		'type'            => 'url',
		'active_callback' => 'travellable_is_blog_section_enabled',
	)
);
